@@ -1,5 +1,5 @@
 /*  GNU moe - My Own Editor
-    Copyright (C) 2005-2017 Antonio Diaz Diaz.
+    Copyright (C) 2005-2019 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -239,12 +239,15 @@ int Buffer::set_marks()
         if( blank( i ) ) { mark[0].line = i; ++c; break; }
     if( mark[0].line < 0 && lines() > 22 ) { mark[0].line = 22; ++c; }
     }
-  for( int i = 1; i < 10 && 100 * i <= lines(); ++i )
+  for( long i = 1; i < 10; ++i )
     {
+    const int line =
+      ( lines() <= 1000 ) ? 100 * i - 1 : ( lines() * i + 9 ) / 10 - 1;
+    if( line >= lines() ) break;
     if( mark[i].line >= 0 )
       for( int j = i - 1; j >= 0; --j )
         if( mark[i] == mark[j] ) { mark[i].line = -1; break; }
-    if( mark[i].line < 0 ) { mark[i].line = 100 * i - 1; ++c; }
+    if( mark[i].line < 0 ) { mark[i].line = line; ++c; }
     }
   return c;
   }
@@ -253,18 +256,21 @@ int Buffer::set_marks()
 bool Buffer::save( const std::string * namep, const bool set_name,
                    const bool append, Point p1, Point p2 ) const
   {
+  const bool save_as = ( namep && namep->size() );
+  if( options.read_only && ( !save_as || name_ == *namep || name_.empty() ) )
+    return false;
   int mode = 0;
   struct stat st;
   if( append ) mode = S_IRUSR | S_IWUSR;
-  else if( ( namep && namep->size() && stat( namep->c_str(), &st ) == 0 ) ||
-           ( name_.size() && stat( name_.c_str(), &st ) == 0 ) )
-         mode = st.st_mode;
+  else if( ( save_as && stat( namep->c_str(), &st ) == 0 ) ||
+           ( name_.size() && ( !save_as || name_ != *namep ) &&
+             stat( name_.c_str(), &st ) == 0 ) ) mode = st.st_mode;
 
   const bool had_name = ( name_.size() > 0 );
   bool same_name = set_name;
   if( set_name )
     {
-    if( namep && namep->size() )
+    if( save_as )
       {
       if( name_ != *namep )
         {
@@ -272,7 +278,8 @@ bool Buffer::save( const std::string * namep, const bool set_name,
         if( f )
           {
           std::fclose( f );
-          int key = Screen::show_message( "File exists. Overwrite ? (y/N) ", true, true );
+          int key = Screen::show_message( "File exists. Overwrite ? (y/N) ",
+                                          true, true );
           if( key != 'y' && key != 'Y' ) return false;
           }
         }
