@@ -1,5 +1,5 @@
 /*  GNU moe - My Own Editor
-    Copyright (C) 2005-2017 Antonio Diaz Diaz.
+    Copyright (C) 2005-2019 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -82,7 +82,7 @@ const char * Bufhandle_vector::save_all_named()
     if( buffer.modified() && buffer.name().size() )
       {
       try { if( buffer.save() ) ++count; else done = false; }
-      catch( Buffer::Error ) { done = false; }
+      catch( Buffer::Error & ) { done = false; }
       }
     }
   Screen::show_status_lines();
@@ -219,3 +219,13 @@ bool Bufhandle_vector::delete_handle( int i )
     { --last_visited_; last_visited_ += handles(); last_visited_ %= handles(); }
   return true;
   }
+
+
+void Bufhandle_vector::delete_all_handles()
+  {
+  for( int i = 0; i < handles(); ++i ) data[i].buffer().handnum = i;
+  for( int i = handles() - 1; i >= 0; --i )
+    if( data[i].buffer().handnum == i )
+      delete &data[i].buffer();		// last handle for this buffer
+  data.clear(); first_ = 0; last_visited_ = 0; Block::reset();
+  }
