@@ -1,5 +1,5 @@
 /*  GNU moe - My Own Editor
-    Copyright (C) 2005-2017 Antonio Diaz Diaz.
+    Copyright (C) 2005-2019 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
 
 namespace Encoding {
 
-// Charset independent Base64 alphabet (RFC 3548).
+// Charset independent Base64 alphabet (RFC 4648).
 //
 int base64_value( const unsigned char ch )
   {
@@ -249,7 +249,11 @@ int map_to_byte( const int code )
     case 0x01D4: return 'u';	// latin small letter u with caron
     case 0x0232: return 'Y';	// latin capital letter y with macron
     case 0x0233: return 'y';	// latin small letter y with macron
+    case 0x0374: return '\'';	// greek numeral sign
+    case 0x0375: return ',';	// greek lower numeral sign
     case 0x037E: return ';';	// greek question mark
+    case 0x0384: return '\'';	// greek tonos
+    case 0x0385: return '"';	// greek dialytika tonos
     case 0x0386: return 0xC1;	// greek capital letter alpha with tonos
     case 0x0387: return 0xB7;	// greek ano teleia
     case 0x0388: return 0xC9;	// greek capital letter epsilon with tonos
@@ -258,6 +262,7 @@ int map_to_byte( const int code )
     case 0x038C: return 0xD3;	// greek capital letter omicron with tonos
     case 0x038E: return 0xDD;	// greek capital letter upsilon with tonos
     case 0x038F: return 0xD3;	// greek capital letter omega with tonos
+    case 0x0390: return 0xEF;	// greek small letter iota with dialytika tonos
     case 0x0391: return 'A';	// greek capital letter alpha
     case 0x0392: return 'B';	// greek capital letter beta
     case 0x0393: return 'G';	// greek capital letter gamma
@@ -312,6 +317,19 @@ int map_to_byte( const int code )
     case 0x03CC: return 0xF3;	// greek small letter omicron with tonos
     case 0x03CD: return 0xFD;	// greek small letter upsilon with tonos
     case 0x03CE: return 0xF3;	// greek small letter omega with tonos
+    case 0x03D0: return 'b';	// greek beta symbol
+    case 0x03D2: return 'Y';	// greek upsilon with hook symbol
+    case 0x03D3: return 0xDD;	// greek upsilon with acute and hook symbol
+    case 0x03D4: return 0xBE;	// greek upsilon with diaeresis and hook symbol
+    case 0x03D5: return 'f';	// greek phi symbol
+    case 0x03D6: return 'p';	// greek pi symbol
+    case 0x03D7: return '&';	// greek kai symbol
+    case 0x03F0: return 'k';	// greek kappa symbol
+    case 0x03F1: return 'r';	// greek rho symbol
+    case 0x03F2: return 's';	// greek lunate sigma symbol
+    case 0x03F3: return 'j';	// greek letter yot
+    case 0x03F5: return 'e';	// greek lunate epsilon symbol
+    case 0x03F9: return 'S';	// greek capital lunate sigma symbol
     case 0x0400: return 0xC8;	// cyrillic capital letter ie with grave
     case 0x0401: return 0xCB;	// cyrillic capital letter io
     case 0x0402: return 'D';	// cyrillic capital letter dje
@@ -634,6 +652,8 @@ const char * map_to_string( const int code )
     case 0x03B8: return "th";	// greek small letter theta
     case 0x03C7: return "ch";	// greek small letter chi
     case 0x03C8: return "ps";	// greek small letter psi
+    case 0x03D1: return "th";	// greek theta symbol
+    case 0x03F4: return "TH";	// greek capital theta symbol
     case 0x0416: return "Zh";	// cyrillic capital letter zhe
     case 0x0427: return "Ch";	// cyrillic capital letter che
     case 0x0428: return "Sh";	// cyrillic capital letter sha
