@@ -1,5 +1,5 @@
 /*  GNU moe - My Own Editor
-    Copyright (C) 2005-2017 Antonio Diaz Diaz.
+    Copyright (C) 2005-2019 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -41,25 +41,28 @@
 
 namespace {
 
-const char * const     Program_name = "GNU moe";
 const char * const     program_name = "moe";
 const char * const config_file_name = "moerc";
-const char * const     program_year = "2017";
+const char * const     program_year = "2019";
 const char * invocation_name = 0;
 
 
 void show_help()
   {
-  std::printf( "%s is a powerful, 8-bit clean, console text editor for ISO-8859 and\n"
+  std::printf( "GNU moe is a powerful, 8-bit clean, console text editor for ISO-8859 and\n"
                "ASCII character encodings. It has a modeless, user-friendly interface,\n"
                "online help, multiple windows, unlimited undo/redo capability, unlimited\n"
                "line length, unlimited buffers, global search/replace (on all buffers at\n"
                "once), block operations, automatic indentation, word wrapping, file name\n"
                "completion, directory browser, duplicate removal from prompt histories,\n"
                "delimiter matching, text conversion from/to UTF-8, romanization, etc.\n"
-               "\nMoe can easily edit thousands of files at the same time.\n", Program_name );
-  std::printf( "\nUsage: %s [global_options] [[+line[,col]] file_name [file_options]]...\n", invocation_name );
-  std::printf( "\n'global_options' are a mix of editor options and default file_options.\n"
+               "\nMoe can easily edit thousands of files at the same time.\n"
+               "\nMoe uses ISO-8859-15 instead of UTF-8 because an 8-bit character set\n"
+               "(combined with romanization if needed) can convey meaning safely and more\n"
+               "efficiently than UTF-8 can.\n"
+               "\nUsage: %s [global_options] [[+line[,col]] file_name [file_options]]...\n",
+               invocation_name );
+  std::printf( "\n'global_options' are a mix of editor options and default 'file_options'.\n"
                "Most long option names have a negative form '--backup' '--no-backup'.\n"
                "\nEach file name may be preceded by '+line[,column]' to start the cursor\n"
                "at the specified line and, optionally, column. 'line' and 'column' are\n"
@@ -89,10 +92,10 @@ void show_help()
                "  -o, --read-only          make buffer read-only\n"
                "  -O, --overwrite          disable insert mode\n"
                "  -w, --word-wrap          enable word wrapping\n"
-               "\nExit status: 0 for a normal exit, 1 for environmental problems (file\n"
-               "not found, invalid flags, I/O errors, etc), 2 to indicate a corrupt or\n"
-               "invalid input file, 3 for an internal consistency error (eg, bug) which\n"
-               "caused moe to panic.\n"
+               "\nExit status: 0 for a normal exit, 1 for environmental problems (file not\n"
+               "found, invalid flags, I/O errors, etc), 2 to indicate a corrupt or invalid\n"
+               "input file, 3 for an internal consistency error (eg, bug) which caused moe\n"
+               "to panic.\n"
                "\nReport bugs to bug-moe@gnu.org\n"
                "Moe home page: http://www.gnu.org/software/moe/moe.html\n"
                "General help using GNU software: http://www.gnu.org/gethelp\n" );
@@ -205,11 +208,9 @@ void RC::show_error( const char * const msg, const int errcode,
                      const bool help )
   {
   if( msg && msg[0] )
-    {
-    std::fprintf( stderr, "%s: %s", program_name, msg );
-    if( errcode > 0 ) std::fprintf( stderr, ": %s", std::strerror( errcode ) );
-    std::fputc( '\n', stderr );
-    }
+    std::fprintf( stderr, "%s: %s%s%s\n", program_name, msg,
+                  ( errcode > 0 ) ? ": " : "",
+                  ( errcode > 0 ) ? std::strerror( errcode ) : "" );
   if( help )
     std::fprintf( stderr, "Try '%s --help' for more information.\n",
                   invocation_name );
