@@ -1,5 +1,5 @@
 /*  GNU moe - My Own Editor
-    Copyright (C) 2005-2017 Antonio Diaz Diaz.
+    Copyright (C) 2005-2019 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -36,9 +36,8 @@ namespace Menu {
 
 void show( const std::vector< std::string > & name_vector, const int lines,
            const int columns, const int current, Point & cursor,
-           const bool indicator = false )
+           int & top_line, const bool indicator = false )
   {
-  static int top_line = 0;
   const int entries = name_vector.size();
   const int bottom_line = ( entries - 1 ) / columns;
   if( bottom_line - top_line + 1 < lines )
@@ -138,6 +137,7 @@ void split_filename( const std::string & name,
 //
 int Menu::bufhandle_menu( int current, const int abort_key )
   {
+  static int top_line = 0;		// keep top line between calls
   std::vector< std::string > name_vector;
 
   const char * const indicator[4] = { " ", "*", "-", "+" };
@@ -151,7 +151,7 @@ int Menu::bufhandle_menu( int current, const int abort_key )
     name_vector.push_back( tmp );
     }
 
-  if( entries < 2 || entries != (int)name_vector.size() ) return -1;
+  if( entries < 1 || entries != (int)name_vector.size() ) return -1;
 
   int max_width = 0;
   for( int i = 0; i < entries; ++i )
@@ -168,12 +168,13 @@ int Menu::bufhandle_menu( int current, const int abort_key )
 
   Screen::save_lines_and_cursor( line, lines + 1 );
 
-  Screen::out_line( "Select buffer handle, F1-F10 or first char (^C to abort)", Screen::height() - 1 );
+  Screen::out_line( "Select buffer handle, F1-F10 or first char (^C to abort)",
+                    Screen::height() - 1 );
   current = Bufhandle_vector::absolute_index( current );
   int key = 0;
   while( key >= 0 )
     {
-    show( name_vector, lines, columns, current, cursor, true );
+    show( name_vector, lines, columns, current, cursor, top_line, true );
     Screen::move_to( Point( line, 0 ) + cursor );
     bool valid_key = false;
     while( !valid_key )
@@ -231,22 +232,28 @@ bool Menu::file_menu( const std::string & prompt, std::string & name )
 
   DIR * const dirp = opendir( dirname.size() ? dirname.c_str() : "./" );
   if( !dirp ) return true;
+  bool dd = false;
+  const std::string dotdot( ".." );		// put ".." always first
+  if( Regex::match_filename( basename, dotdot ) )
+    { name_vector.push_back( dotdot ); dd = true; }
   while( true )
     {
     const struct dirent * const entryp = readdir( dirp );
     if( !entryp ) { closedir( dirp ); break; }
     std::string tmp( entryp->d_name );
-    if( tmp != "." && Regex::match_filename( basename, tmp ) )
+    if( tmp != "." && tmp != ".." && Regex::match_filename( basename, tmp ) )
       name_vector.push_back( tmp );
     }
-  if( name_vector.size() > 1 )
-    { name = dirname; append_common_prefix( name, name_vector ); }
-
   const int entries = name_vector.size();
-  if( !entries ) return true;
-  if( entries > 1 ) std::sort( name_vector.begin(), name_vector.end() );
+  if( entries > 1 )
+    {
+    name = dirname; append_common_prefix( name, name_vector );
+    std::sort( name_vector.begin() + dd, name_vector.end() );
+    }
+  else if( !entries ) return true;
 
-  if( entries == 1 || ( entries == 2 && name_vector[0] == ".." ) )
+  if( entries == 1 ||
+    ( entries == 2 && name_vector[0] == ".." && name_vector[1][0] != '.' ) )
     { name = dirname + name_vector.back(); append_slash_if_dir( name );
       return true; }
 
@@ -265,10 +272,10 @@ bool Menu::file_menu( const std::string & prompt, std::string & name )
 
   Screen::save_lines_and_cursor( line, lines + 1 );
 
-  int current = 0, key = 0;
+  int current = 0, key = 0, top_line = 0;
   while( key >= 0 )
     {
-    show( name_vector, lines, columns, current, cursor );
+    show( name_vector, lines, columns, current, cursor, top_line );
     Screen::out_line( prompt + name, Screen::height() - 1, true );
     Screen::move_to( Point( line, 0 ) + cursor );
     bool valid_key = false;
