@@ -1,5 +1,5 @@
 /*  GNU moe - My Own Editor
-    Copyright (C) 2005-2017 Antonio Diaz Diaz.
+    Copyright (C) 2005-2019 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -41,15 +41,15 @@ const char * help_line[] = {
   " ^[O Offset             ^QU update (C)              ^Y   Delete line",
   " ^[B Beg of block                                   ^OC  Center line",
   " ^[K End of block       @bINFO@b                        ^ON  Change buffer name",
-  " ^[F Match pair ->      ^A   Show help              ^OR  Repaint screen",
+  " ^[F Match pair ->      ^A   Show help (^H)         ^OR  Repaint screen",
   " ^[G Match pair <-      ^[I  Show character info    ^OS  Split window",
   " ^[D Center cursor      ^[T  Show UTF-8 code        ^Q@bF2@b Save named buffers",
   "                        ^Sn  Show LE multibyte",
   " @bSCROLL@b                 ^S@bFn@b Show BE multibyte      @bBOOKMARKS@b",
   " ^[W Up                 ^SC  Show character code    ^[ 0-9 Goto",
   " ^[Z Down               ^SG  Show global status     ^K 0-9 Set",
-  " ^[A Left               ^SV  Show version           ^KE    Extend",
-  " ^[S Right",
+  " ^[A Left               ^SP  Show line position     ^KE    Extend",
+  " ^[S Right              ^SV  Show version",
   "",
   " Help Screen: Block Commands     PAGE_DN next/PAGE_UP prev",
   " ",
@@ -64,6 +64,7 @@ const char * help_line[] = {
   " ^KW Write                 ^O2 Base64",
   " ^KI Indent                ^O6 Quoted-Printable",
   " ^KU Unindent              ^O8 UTF-8",
+  " ^OK Capitalize",
   " ^OL To lowercase",
   " ^OU To uppercase",
   " ",
@@ -71,7 +72,6 @@ const char * help_line[] = {
   " ",
   " ",
   " ",
-  " ",
   " ^[X means Alt-X or Esc-X    ^X means Control-X",
   " ",
   " See manual (moe.info) for a complete explanation of moe's commands.",
