@@ -1,5 +1,5 @@
 /*  GNU moe - My Own Editor
-    Copyright (C) 2005-2017 Antonio Diaz Diaz.
+    Copyright (C) 2005-2019 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -294,8 +294,31 @@ void apply_regex_options( Buffer & buffer )
   }
 
 
+bool unwanted_name( const std::string & name )
+  {
+  const char * const ext1[] = { "a", "o", "z", "Z", 0 };
+  const char * const ext2[] = { "gz", "lz", "mo", "po", "ps", "so", "xz", 0 };
+  const char * const ext3[] = { "bz2", "deb", "dll", "dvi", "gif", "gmo",
+    "ico", "jar", "jpg", "pbm", "pdf", "pgm", "png", "ppm", "rpm", "svg",
+    "tar", "tgz", "tif", "tlz", "txz", "wav", 0 };
+  const char * const ext4[] = { "rpms", "svgz", 0 };
+  const char * const * ext[4] = { ext1, ext2, ext3, ext4 };
+
+  if( name == "." || name == ".." || name.empty() ||
+      name[name.size()-1] == '~' ) return true;
+  for( unsigned i = 0; i < 4; ++i )
+    {
+    if( name.size() <= i + 2 ) break;
+    if( name[name.size()-i-2] != '.' ) continue;
+    for( const char * const * p = ext[i]; *p; ++p )
+      if( name.compare( name.size() - i - 1, i + 1, *p ) == 0 ) return true;
+    }
+  return false;
+  }
+
+
 // Depth first. Files first in each directory. Load regular files only.
-// Ignore backups '*~', object files '*.o' and symbolic links.
+// Ignore backups '*~', unwanted names and symbolic links.
 bool add_handles_recursively( std::string name, const int line, const int col,
                               const File_options & file_options,
                               bool & first_post, bool & read_error_found )
@@ -323,10 +346,7 @@ bool add_handles_recursively( std::string name, const int line, const int col,
       const struct dirent * const entryp = readdir( dirp );
       if( !entryp ) { closedir( dirp ); break; }
       std::string tmp( entryp->d_name );
-      if( tmp == "." || tmp == ".." || tmp.empty() ||
-          tmp[tmp.size()-1] == '~' ||
-          ( tmp.size() > 2 && tmp.compare( tmp.size() - 2, 2, ".o" ) == 0 ) )
-        continue;
+      if( unwanted_name( tmp ) ) continue;
       if( !isdot ) tmp = dirname + "/" + tmp;
       name_vector.push_back( tmp );
       }
@@ -359,7 +379,7 @@ bool add_handles_recursively( std::string name, const int line, const int col,
             apply_file_options( Bufhandle_vector::handle( h ).buffer(),
                                 file_options );
             }
-          catch( Buffer::Error e )
+          catch( Buffer::Error & e )
             {
             if( first_post ) { first_post = false; std::fputc( '\n', stderr ); }
             std::fprintf( stderr, "warning: '%s': %s\n",
@@ -565,7 +585,7 @@ int RC::process_options()
                                                             col, can_read );
         apply_file_options( Bufhandle_vector::handle( i ).buffer(), file_options );
         }
-      catch( Buffer::Error e )
+      catch( Buffer::Error & e )
         {
         if( first_post ) { first_post = false; std::fputc( '\n', stderr ); }
         std::fprintf( stderr, "warning: '%s': %s\n", name.c_str(), e.msg );
@@ -583,7 +603,7 @@ int RC::process_options()
     }
   // Add empty buffer if no files given or stdin is not a tty
   try { Bufhandle_vector::add_handle_if_pending_input_or_empty( line, col ); }
-  catch( Buffer::Error e )
+  catch( Buffer::Error & e )
     {
     if( first_post ) std::fputc( '\n', stderr );
     show_error( e.msg );
