@@ -1,5 +1,5 @@
 /*  GNU moe - My Own Editor
-    Copyright (C) 2005-2017 Antonio Diaz Diaz.
+    Copyright (C) 2005-2019 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,14 +21,16 @@ class Options
   {
   int indent_step_, keep_lines_, max_windows_;
 public:
-  bool auto_unmark, backup, /*beep,*/ exit_ask, ignore_case;
-  bool orphan_extra, rectangle_mode, search_wrap, show_code, smart_home;
+  int show_code_lpos;			// 1 show code, 2 show lpos
+  bool auto_unmark, backup, /*beep,*/ exit_ask, ignore_case, orphan_extra;
+  bool rectangle_mode, search_wrap, smart_home;
 
   Options()
     : indent_step_( 2 ), keep_lines_( -1 ), max_windows_( 0 ),
+    show_code_lpos( 0 ),
     auto_unmark( false ), backup( true ), /*beep( false ),*/ exit_ask( false ),
     ignore_case( false ), orphan_extra( false ), rectangle_mode( false ),
-    search_wrap( false ), show_code( false ), smart_home( true ) {}
+    search_wrap( false ), smart_home( true ) {}
 
   int indent_step() const { return indent_step_; }
   int keep_lines() const { return keep_lines_; }
