@@ -1,5 +1,5 @@
 /*  GNU moe - My Own Editor
-    Copyright (C) 2005-2017 Antonio Diaz Diaz.
+    Copyright (C) 2005-2019 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -313,7 +313,7 @@ int Regex::find( const Basic_buffer & buffer, Point & p1, Point & p2,
   if( regex.empty() ) return 0;
   if( pieces.size() ) pieces.clear();
 
-  const int bs = regex.find('\\');
+  const unsigned bs = regex.find('\\');
   if( bs > 0 )
     {
     const std::string header( regex, 0, bs );
@@ -408,7 +408,7 @@ bool Regex::replace( Buffer & buffer, const Point & p1, Point & p2,
   }
 
 
-// Returns true if 'regex' matches 'name'
+// Returns true if 'regex' from i1 matches 'name' from i2
 //
 bool Regex::match_filename( const std::string & regex, const std::string & name,
                             unsigned i1, unsigned i2 )
