@@ -1,5 +1,5 @@
 /*  GNU moe - My Own Editor
-    Copyright (C) 2005-2017 Antonio Diaz Diaz.
+    Copyright (C) 2005-2019 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -240,12 +240,13 @@ const char * control_o_loop( int key )
     case 'D': msg = Window_vector::remove_duplicate_lines(); break;
     case 'E': msg = Window_vector::remove_duplicate_lines( true ); break;
     case 'F': msg = Window_vector::search( 6, true, "", 2 ); break;
-    case 'L': msg = Window_vector::change_case( false ); break;
+    case 'K': msg = Window_vector::change_case( 2 ); break;
+    case 'L': msg = Window_vector::change_case( 0 ); break;
     case 'N': msg = Window_vector::change_buffer_name(); break;
     case 'O': msg = Window_vector::remove_utf8_out_of_range(); break;
     case 'R': werase( stdscr ); wrefresh( stdscr ); repaint(); break;
     case 'S': Window_vector::split_window(); break;
-    case 'U': msg = Window_vector::change_case( true ); break;
+    case 'U': msg = Window_vector::change_case( 1 ); break;
     }
   return msg;
   }
@@ -287,9 +288,13 @@ const char * control_s_loop( int key, const char * const version_msg )
     case '2':
     case '4':
     case '8': msg = w.show_multichar_value( key - '0', false ); break;
-    case 'C': RC::editor_options().show_code = !RC::editor_options().show_code;
+    case 'C': RC::editor_options().show_code_lpos =
+                ( RC::editor_options().show_code_lpos == 1 ) ? 0 : 1;
               show_status_lines(); break;
     case 'G': msg = Bufhandle_vector::show_status(); break;
+    case 'P': RC::editor_options().show_code_lpos =
+                ( RC::editor_options().show_code_lpos == 2 ) ? 0 : 2;
+              show_status_lines(); break;
     case 'V': msg = version_msg; break;
     }
   return msg;
@@ -350,7 +355,8 @@ const char * user_control_char( const int abort_key )
     key = show_message( prompt1, false, true );
     if( key == 1 || key == 8 || key == KEY_F(1) )
       { wait_kbhit(); Menu::help_menu( 1, 8, KEY_F(1) ); }
-    else if( key == 3 || key == abort_key ) { wait_kbhit(); return 0; }	// ^C
+    else if( key == 3 || key == '\n' || key == abort_key )	// ^C
+      { wait_kbhit(); return 0; }
     else if( key >= 256 || key == '\\' || std::isalnum( key ) ) break;
     else wait_kbhit();
     }
@@ -750,7 +756,7 @@ void Screen::show_feedback( const std::string & s )
 
 
 int Screen::show_message( const std::string & s, const bool get_key,
-                          const bool take_cursor )
+                          const bool take_cursor, const bool discard_cc )
   {
   const int line = height_ - 1;
 
@@ -758,7 +764,7 @@ int Screen::show_message( const std::string & s, const bool get_key,
 
   out_string( line, 0, s, width_ );
   wmove( stdscr, line, std::min( (int)s.size(), width_ - 1 ) );
-  discard_control_c();
+  if( discard_cc ) discard_control_c();
   int key;
   do key = wait_kbhit( take_cursor ? line : -1, get_key ); while( key < 0 );
 
