@@ -1,5 +1,5 @@
 /*  GNU moe - My Own Editor
-    Copyright (C) 2005-2017 Antonio Diaz Diaz.
+    Copyright (C) 2005-2019 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -69,7 +69,7 @@ bool out_menu_line( const std::string & s, const int line,
 void repaint( const Buffer * const bufp = 0 );
 void show_feedback( const std::string & s );
 int show_message( const std::string & s, const bool get_key = false,
-                  const bool take_cursor = false );
+                  const bool take_cursor = false, const bool discard_cc = true );
 void show_status_lines( const Buffer * const bufp = 0 );
 
 Keys convert_key( const int key );
