@@ -1,5 +1,5 @@
 /*  GNU moe - My Own Editor
-    Copyright (C) 2005-2017 Antonio Diaz Diaz.
+    Copyright (C) 2005-2019 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -500,14 +500,23 @@ void Window::show_status_line( const char * const prefix ) const
   snprintf( buf + offset, bufsize - offset,
             "  Line %-4d Col %-3d %5s   F1 for help",
             line, col, Screen::clock_string() );
-  if( RC::editor_options().show_code )
+  if( RC::editor_options().show_code_lpos )
     {
     offset = bufsize - 13;
-    const int ch = buffer[bhp->pointer];
-    if( ch >= 0 )
-      snprintf( buf + offset, bufsize - offset, "%3d(0x%02X)", ch, ch );
+    if( RC::editor_options().show_code_lpos == 1 )
+      {
+      const int ch = buffer[bhp->pointer];
+      if( ch >= 0 )
+        snprintf( buf + offset, bufsize - offset, "%3d(0x%02X)", ch, ch );
+      else
+        snprintf( buf + offset, bufsize - offset, "End of file" );
+      }
     else
-      snprintf( buf + offset, bufsize - offset, "End of file" );
+      {
+      const int lpos = ( line <= 1 ) ? 0 : ( line >= buffer.lines() ) ? 100 :
+                       ( 100LL * line ) / buffer.lines();
+      snprintf( buf + offset, bufsize - offset, "Lpos %d%%", lpos );
+      }
     }
   Screen::out_line( buf, top_line_, false, 'i' );
   }
