@@ -1,5 +1,5 @@
 /*  GNU moe - My Own Editor
-    Copyright (C) 2005-2017 Antonio Diaz Diaz.
+    Copyright (C) 2005-2019 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -247,7 +247,8 @@ int Window_vector::load( int new_size )
     data.push_back( Window( Bufhandle_vector::handle( i ), y, wheight, center ) );
     ++i; y += wheight;
     }
-  data.push_back( Window( Bufhandle_vector::handle( i ), y, Screen::height() - y, center ) );
+  data.push_back( Window( Bufhandle_vector::handle( i ), y,
+                          Screen::height() - y, center ) );
   if( toggle && data.size() == 1 ) data[0].center_cursor();
   for( i = 0; i < (int)data.size(); ++i ) data[i].repaint();
   return data.size();
@@ -288,7 +289,7 @@ const char * Window_vector::load_file( const int abort_key )
   const int old_handles = Bufhandle_vector::handles();
   int handle;
   try { handle = Bufhandle_vector::find_or_add_handle( &name, curwin_ + 1 ); }
-  catch( Buffer::Error e ) { return e.msg; }
+  catch( Buffer::Error & e ) { return e.msg; }
   curwin_ = handle;
   if( windows() > 1 && Bufhandle_vector::handles() > old_handles )
     load( windows() + 1 );
@@ -316,7 +317,7 @@ const char * Window_vector::save_file( const int abort_key )
   if( msg ) return msg;
   bool done;
   try { done = buffer.save( &name ); }
-  catch( Buffer::Error e ) { return e.msg; }
+  catch( Buffer::Error & e ) { return e.msg; }
   if( done )
     {
     Screen::show_status_lines( &buffer );
@@ -344,7 +345,8 @@ int Window_vector::close( bool abort, const bool quiet )
 
     if( abort && modified && last_handle )
       {
-      int key = Screen::show_message( "Lose changes to this file ? (y/n/^C) ", true, true );
+      int key = Screen::show_message( "Lose changes to this file ? (y/n/^C) ",
+                                      true, true );
       if( key == 'n' || key == 'N' ) abort = false;
       else if( key != 'y' && key != 'Y' ) return -1;
       }
@@ -352,11 +354,12 @@ int Window_vector::close( bool abort, const bool quiet )
       {
       if( read_only( bh.buffer() ) ) return -1;
       std::string name( bh.buffer().name() );
-      if( exit_ask || name.empty() )
-        while( !Menu::get_filename( "Name of file to save (^C to abort): ", name ) );
+      if( ( exit_ask || name.empty() ) &&
+          Menu::get_filename( "Name of file to save (^C to abort): ",
+                              name ) <= 0 ) return -1;
       if( name.empty() ) return -1;
       try { if( !bh.buffer().save( &name ) ) return -1; }
-      catch( Buffer::Error e )
+      catch( Buffer::Error & e )
         { if( !quiet ) Screen::show_message( e.msg ); return -1; }
       }
     else if( exit_ask && last_handle && !modified )
@@ -374,12 +377,30 @@ int Window_vector::close( bool abort, const bool quiet )
 int Window_vector::close_and_exit( const bool abort )
   {
   int key;
-  if( abort ) key = Screen::show_message( "Are you sure you want to abort ? (y/N) ", true, true );
-  else key = Screen::show_message( "Are you sure you want to exit ? (y/N) ", true, true );
+  if( abort )
+    key = Screen::show_message( "Are you sure you want to abort ? (y/N) ",
+                                true, true );
+  else key = Screen::show_message( "Are you sure you want to exit ? (y/N) ",
+                                   true, true );
   if( key == 'y' || key == 'Y' )
     {
-    prev();
-    while( data.size() && close( abort, true ) >= 0 );
+    if( !abort )			// save all modified buffers
+      {
+      Bufhandle_vector::save_all_named();
+      for( int i = Bufhandle_vector::handles(); i > 0; next(), --i )
+        {
+        const Buffer & buffer = data[curwin_].buffer();
+        if( buffer.modified() )
+          {
+          if( read_only( buffer ) ) return data.size();	//can't save
+          const char * const msg = save_file();
+          if( buffer.modified() )			// not saved
+            { if( msg ) Screen::show_message( msg ); return data.size(); }
+          }
+        }
+      }
+    if( data.size() > 1 ) load( 1 );
+    Bufhandle_vector::delete_all_handles(); curwin_ = 0; data.clear();
     }
   return data.size();
   }
@@ -541,7 +562,7 @@ const char * Window_vector::read_block()
     if( w.buffer().pputb( p, tmp, tmp.bof(), tmp.eof() ) )
       Screen::repaint( &w.buffer() );
     }
-  catch( Buffer::Error e ) { return e.msg; }
+  catch( Buffer::Error & e ) { return e.msg; }
   return 0;
   }
 
@@ -569,7 +590,7 @@ const char * Window_vector::write_block()
       Block::reset(); Screen::repaint( bufferp );
       }
     }
-  catch( Buffer::Error e ) { return e.msg; }
+  catch( Buffer::Error & e ) { return e.msg; }
   return 0;
   }
 
@@ -771,7 +792,9 @@ const char * Window_vector::reformat()
   }
 
 
-const char * Window_vector::change_case( const bool to_caps )
+// Can't use to_lowercase, etc, because of rectangle mode.
+// Can't change characters in place because of atomic undo.
+const char * Window_vector::change_case( const int caps_level )
   {
   Buffer & buffer = data[curwin_].buffer();
   if( no_block() || no_block_in_this_file( buffer ) || read_only( buffer ) )
@@ -779,24 +802,29 @@ const char * Window_vector::change_case( const bool to_caps )
   Basic_buffer tmp;
   Point p = tmp.bof();
   bool change = false;
-  if( to_caps )
-    for( Point p1 = Block::begin(); p1 < Block::end(); )
+  bool prev_is_alnum = false;
+  for( Point p1 = Block::begin(); p1 < Block::end(); )
+    {
+    const bool in_block = Block::in_block( buffer, p1 );
+    unsigned char ch = buffer.pgetc( p1 );
+    switch( caps_level )
       {
-      const bool in_block = Block::in_block( buffer, p1 );
-      unsigned char ch = buffer.pgetc( p1 );
-      if( in_block && ISO_8859::islower( ch ) )
-        { ch = ISO_8859::toupper( ch ); change = true; }
-      tmp.pputc( p, ch );
-      }
-  else
-    for( Point p1 = Block::begin(); p1 < Block::end(); )
-      {
-      const bool in_block = Block::in_block( buffer, p1 );
-      unsigned char ch = buffer.pgetc( p1 );
-      if( in_block && ISO_8859::isupper( ch ) )
-        { ch = ISO_8859::tolower( ch ); change = true; }
-      tmp.pputc( p, ch );
+      case 0: if( in_block && ISO_8859::isupper( ch ) )
+                { ch = ISO_8859::tolower( ch ); change = true; } break;
+      case 1: if( in_block && ISO_8859::islower( ch ) )
+                { ch = ISO_8859::toupper( ch ); change = true; } break;
+      case 2: {
+              if( !in_block ) { prev_is_alnum = false; break; }
+              const bool is_alnum = ISO_8859::isalnum_( ch );
+              if( prev_is_alnum && ISO_8859::isupper( ch ) )
+                { ch = ISO_8859::tolower( ch ); change = true; }
+              if( !prev_is_alnum && ISO_8859::islower( ch ) )
+                { ch = ISO_8859::toupper( ch ); change = true; }
+              prev_is_alnum = is_alnum;
+              }
       }
+    tmp.pputc( p, ch );
+    }
   if( !change ) return "No letters to change in block";
   replace_and_repaint( buffer, tmp );
   return 0;
@@ -817,7 +845,7 @@ void Window_vector::encode_base64()
   for( unsigned i = 0; i < out.size(); ++i )
     {
     tmp.pputc( p, out[i] );
-    if( ++c >= 72 ) { c = 0; tmp.pputc( p, '\n' ); }
+    if( ++c >= 76 ) { c = 0; tmp.pputc( p, '\n' ); }
     }
   if( c ) tmp.pputc( p, '\n' );
   replace_and_repaint( buffer, tmp );
@@ -1030,7 +1058,7 @@ const char * Window_vector::copyright_update()
     {
     int year = 1900 + t->tm_year;
     while( year )
-      { year_string.insert( 0U, 1, '0' + ( year % 10 ) ); year /= 10; }
+      { year_string.insert( 0U, 1U, '0' + ( year % 10 ) ); year /= 10; }
     }
   history.push_back( year_string );
   if( Screen::get_string( "Year to add (^C to abort): ", history ) <= 0 )
@@ -1046,7 +1074,7 @@ const char * Window_vector::copyright_update()
       new_year < 1000 || new_year > 9999 ) return "Invalid year";
   bool ask = true, found = false, modified = false, outdated = false;
   bool skipped = false;
-  for( int i = 0; i < Bufhandle_vector::handles(); next(), ++i )
+  for( int i = Bufhandle_vector::handles(); i > 0; next(), --i )
     {
     Window & w = data[curwin_];
     if( w.buffer().options.read_only ) { skipped = true; continue; }
@@ -1075,7 +1103,8 @@ const char * Window_vector::copyright_update()
         int key = 0;
         if( ask || Screen::kbhit() >= 0 )
           {
-          key = Screen::show_message( "Update (Y)es (N)o (R)est (^C to abort): ", true );
+          key = Screen::show_message( "Update (Y)es (N)o (R)est (^C to abort): ",
+                                      true );
           if( key == 3 ) return 0;
           if( ask && ( key == 'r' || key == 'R' ) ) ask = false;
           }
@@ -1182,7 +1211,7 @@ const char * Window_vector::search( const int abort_key, const bool again,
     if( block ) global = false;
     if( replace )
       {
-      replace_string.clear();
+      replace_string.clear();		// by default replace with nothing
       replace_history.push_back( std::string() );
       const int len = Screen::get_string( "Replace with (^C to abort): ",
                                           replace_history, abort_key );
@@ -1217,7 +1246,7 @@ const char * Window_vector::search( const int abort_key, const bool again,
         Screen::show_feedback( ask ? "searching..." : "replacing..." ); }
     Window & w = data[curwin_];
     std::vector< std::string > regex_pieces;
-    if( replace && empty_replace && !backward ) w.buffer().pnext( p );
+//    if( replace && empty_replace && !backward ) w.buffer().pnext( p );
     Point p1 = p, p2 = p;
     { const int tmp = Regex::find( w.buffer(), p1, p2, search_string,
                                    regex_pieces, icase, backward );
@@ -1249,7 +1278,8 @@ const char * Window_vector::search( const int abort_key, const bool again,
         int key = 0;
         if( ask || Screen::kbhit() >= 0 )
           {
-          key = Screen::show_message( "Replace (Y)es (N)o (R)est (^C to abort): ", true );
+          key = Screen::show_message( "Replace (Y)es (N)o (R)est (^C to abort): ",
+                                      true, false, false );
           if( key == 3 ) { if( !ask ) msg = "Interrupted"; break; }
           if( ask )
             {
@@ -1260,6 +1290,8 @@ const char * Window_vector::search( const int abort_key, const bool again,
         if( !ask || key == 'y' || key == 'Y' )
           {
           Block::restore_block_position();
+          if( !ask && empty_replace )
+            { msg = "Infinite replacement loop"; break; }
           if( !ask && prev_replace == &w.buffer() ) w.buffer().force_append();
           const bool done =
             Regex::replace( w.buffer(), p1, p2, replace_string, regex_pieces );
