@@ -1,5 +1,5 @@
 /*  GNU moe - My Own Editor
-    Copyright (C) 2005-2017 Antonio Diaz Diaz.
+    Copyright (C) 2005-2019 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@ void bufhandle_menu( const int abort_key );
 const char * change_buffer_name();
 const char * load_file( const int abort_key );
 void split_window();
-const char * save_file( const int abort_key );
+const char * save_file( const int abort_key = 3 );
 int close( bool abort, const bool quiet = false );
 int close_and_exit( const bool abort );
 
@@ -50,7 +50,7 @@ const char * redo();
 
 void center_line();
 const char * reformat();
-const char * change_case( const bool to_caps );
+const char * change_case( const int caps_level );
 void encode_base64();
 const char * decode_base64();
 bool encode_ascii_utf8( const char ** const msgp,
